Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2)

Unified Diff: third_party/binutils/build-one.sh

Issue 1670073003: Link binutils with tcmalloc_minimal. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: a comment Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/binutils/build-all.sh ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/binutils/build-one.sh
diff --git a/third_party/binutils/build-one.sh b/third_party/binutils/build-one.sh
index 1a45638a059e7d6144116452fc4ad623146975d0..7611d09035bb2df18718ecb9c739952540cac017 100755
--- a/third_party/binutils/build-one.sh
+++ b/third_party/binutils/build-one.sh
@@ -15,19 +15,39 @@ fi
cd "$1"
+# First, we need to build libtcmalloc_minimal
+
+cd ../gperftools/
+./autogen.sh
+./configure --disable-static --enable-minimal --disable-heap-checker \
+ --disable-heap-profiler --disable-cpu-profiler
+make -j8
+
+cd "$1"
+
# Ask the dynamic loader to load libstdc++ from the LLVM build directory if
# available. That copy of libstdc++ is required by the gold plugin in the same
# directory. The dynamic loader expects the relative path to start with $ORIGIN,
# but because of escaping issues
# (https://sourceware.org/ml/binutils/2009-05/msg00252.html)
# we embed a dummy path with $ replaced with z and fix it up later.
-export LDFLAGS='-Wl,-rpath,zORIGIN/../../../../llvm-build/Release+Asserts/lib'
+
+readonly LIBSTDCPP_RPATH="zORIGIN/../../../../llvm-build/Release+Asserts/lib"
+readonly LIBTCMALLOC_RPATH="zORIGIN/../lib"
+export LDFLAGS="-Wl,-rpath,$LIBSTDCPP_RPATH:$LIBTCMALLOC_RPATH \
+ -L$(pwd)/../gperftools/.libs/"
+export LIBS='-ltcmalloc_minimal'
./configure --enable-gold=default --enable-threads --enable-plugins \
--prefix=/build/output
+
make -j8 all
make install
+# Copy libtcmalloc_minimal library and symlinks to the install lib dir.
+cp -a ../gperftools/.libs/libtcmalloc_minimal.so* /build/output/*/lib/
+
# Save the list of binaries. The sed -i command will leave .orig files behind.
# We don't want them to appear in the for loop below.
bins="$(echo /build/output/*/bin/*)"
@@ -35,9 +55,9 @@ bins="$(echo /build/output/*/bin/*)"
# Fix up zORIGIN -> $ORIGIN.
sed -i.orig 's,zORIGIN,$ORIGIN,g' $bins
-# Verify that we changed only one byte per executable.
+# Verify that we changed only two bytes per executable.
for bin in $bins; do
- test "`cmp -l $bin.orig $bin | wc -l`" = 1 || \
+ test "`cmp -l $bin.orig $bin | wc -l`" = 2 || \
(echo "$bin: verification failed" && exit 1)
done
« no previous file with comments | « third_party/binutils/build-all.sh ('k') | no next file » | no next file with comments »
@@ -15,19 +15,39 @@ fi
# Ask the dynamic loader to load libstdc++ from the LLVM build directory if
# available. That copy of libstdc++ is required by the gold plugin in the same
-# directory. The dynamic loader expects the relative path to start with $ORIGIN,
+# directory. Do the same for libtcmalloc_minimal, that is stored in ../lib.
+# The dynamic loader expects the relative path to start with $ORIGIN,
# but because of escaping issues
# (https://sourceware.org/ml/binutils/2009-05/msg00252.html)

Powered by Google App Engine
This is Rietveld 408576698